[libvirt] [test-API 16/17] Substitute '\<guest\>' with 'domain'

Osier Yang jyang at redhat.com
Fri Apr 20 06:46:22 UTC 2012


% for i in $(grep '\<guest\>' * -r | awk -F':' '{print $1}' | uniq); do \
    sed -i -e 's/\<guest\>/domain/g' $i; \
  done
---
 .../en-US/Understanding_libvirt-test-API.xml       |    4 ++--
 .../en-US/Writing_a_test_case.xml                  |    2 +-
 global.cfg                                         |   20 ++++++++++----------
 repos/domain/attach_disk.py                        |    2 +-
 repos/domain/attach_interface.py                   |    2 +-
 repos/domain/console_io.py                         |    6 +++---
 repos/domain/console_mutex.py                      |    4 ++--
 repos/domain/cpu_affinity.py                       |    2 +-
 repos/domain/cpu_topology.py                       |    2 +-
 repos/domain/destroy.py                            |    2 +-
 repos/domain/detach_disk.py                        |    2 +-
 repos/domain/detach_interface.py                   |    2 +-
 repos/domain/domain_list.py                        |    6 +++---
 repos/domain/eventhandler.py                       |    8 ++++----
 repos/domain/ifstats.py                            |    4 ++--
 repos/domain/install_linux_check.py                |   12 ++++++------
 repos/domain/resume.py                             |    4 ++--
 repos/domain/save.py                               |    2 +-
 repos/domain/shutdown.py                           |    2 +-
 repos/domain/start.py                              |    4 ++--
 repos/domain/suspend.py                            |    2 +-
 .../multiple_thread_block_on_domain_create.py      |    2 +-
 repos/snapshot/delete.py                           |    2 +-
 repos/snapshot/file_flag.py                        |    2 +-
 repos/snapshot/internal_create.py                  |    2 +-
 repos/snapshot/revert.py                           |    2 +-
 utils/utils.py                                     |   12 ++++++------
 27 files changed, 58 insertions(+), 58 deletions(-)

diff --git a/docs/User_Guide/libvirt-test-API_Guide/en-US/Understanding_libvirt-test-API.xml b/docs/User_Guide/libvirt-test-API_Guide/en-US/Understanding_libvirt-test-API.xml
index b065cb1..9f5b93a 100644
--- a/docs/User_Guide/libvirt-test-API_Guide/en-US/Understanding_libvirt-test-API.xml
+++ b/docs/User_Guide/libvirt-test-API_Guide/en-US/Understanding_libvirt-test-API.xml
@@ -62,8 +62,8 @@
           <row>
             <entry><application>Test object</application></entry>
             <entry>Compatibility between libvirt and hypervisor.</entry>
-            <entry>Compatibility and functionality of the guest.</entry>
-            <entry>Functionality testing of the guest.</entry>
+            <entry>Compatibility and functionality of the domain.</entry>
+            <entry>Functionality testing of the domain.</entry>
           </row>
           <row>
             <entry><application>Test purpose</application></entry>
diff --git a/docs/User_Guide/libvirt-test-API_Guide/en-US/Writing_a_test_case.xml b/docs/User_Guide/libvirt-test-API_Guide/en-US/Writing_a_test_case.xml
index 40e365a..0280341 100644
--- a/docs/User_Guide/libvirt-test-API_Guide/en-US/Writing_a_test_case.xml
+++ b/docs/User_Guide/libvirt-test-API_Guide/en-US/Writing_a_test_case.xml
@@ -267,7 +267,7 @@ def install_domain(dict):
     <example>
       <title>Environment configuration file <filename>env.ini</filename></title>
 <programlisting>
-[guest]
+[domain]
 rhel5u4src = http://redhat.com/pub/rhel/rel-eng/RHEL5.4-Server-latest/tree-x86_64
 rhel5u4ks = http://10.00.00.01/ks-rhel-5.4-x86_64-noxen-smp-minimal.cfg
 
diff --git a/global.cfg b/global.cfg
index 1346988..20ce390 100644
--- a/global.cfg
+++ b/global.cfg
@@ -93,7 +93,7 @@ sourcepath = /media/share
 # Test URL file used for checking wget proper functionning within
 # a linux guests, i.e. that network is functionning properly within
 # Using a IP dotted server name as in http://192.168.1.10/wget_test_file
-# will avoid testing DNS resolution in the guest, while a FQDN will
+# will avoid testing DNS resolution in the domain, while a FQDN will
 # also exercise DNS resolution
 #
 [other]
@@ -123,22 +123,22 @@ password =
 
 # default hypervisor used
 defaulthv = kvm
-# default domain name for defining or installing a new guest
+# default domain name for defining or installing a new domain
 defaultname = libvirt_test_api
-# default os version to use for installing a new guest
-# the value of it is the first part of 'rhel6u2_x86_64' in [guest] section above
+# default os version to use for installing a new domain
+# the value of it is the first part of 'rhel6u2_x86_64' in [domain] section above
 defaultos = rhel6u2
-# default architecture to use for installing a new guest
+# default architecture to use for installing a new domain
 defaultarch = x86_64
-# default the number of vcpu to use for defining or installing a guest
+# default the number of vcpu to use for defining or installing a domain
 defaultvcpu = 1
-# default the memory size(kilobytes) to use for defining or installing a guest
+# default the memory size(kilobytes) to use for defining or installing a domain
 defaultmem = 1048576
-# default virtual hd driver for defining or installing a guest
+# default virtual hd driver for defining or installing a domain
 defaulthd = virtio
-# default virtual nic driver for defining or installing a guest
+# default virtual nic driver for defining or installing a domain
 defaultnic = virtio
-# static uuid for define, create and installing a guest
+# static uuid for define, create and installing a domain
 static_uuid = 05867c1a-afeb-300e-e55e-2673391ae080
 # path to a disk image containing a preinstalled domain for testing
 testfullimagepath = /var/lib/libvirt/images/f14.img
diff --git a/repos/domain/attach_disk.py b/repos/domain/attach_disk.py
index 26890ae..b2cf45b 100644
--- a/repos/domain/attach_disk.py
+++ b/repos/domain/attach_disk.py
@@ -90,7 +90,7 @@ def attach_disk(params):
         if  check_attach_disk(disk_num1, disk_num2):
             logger.info("current disk number: %s\n" %disk_num2)
         else:
-            logger.error("fail to attach a disk to guest: %s\n" %disk_num2)
+            logger.error("fail to attach a disk to domain: %s\n" %disk_num2)
             return 1
     except libvirtError, e:
         logger.error("API error message: %s, error code is %s" \
diff --git a/repos/domain/attach_interface.py b/repos/domain/attach_interface.py
index 5868fcb..c22fbd9 100644
--- a/repos/domain/attach_interface.py
+++ b/repos/domain/attach_interface.py
@@ -55,7 +55,7 @@ def attach_interface(params):
         if  check_attach_interface(iface_num1, iface_num2):
             logger.info("current interface number: %s" %iface_num2)
         else:
-            logger.error("fail to attach a interface to guest: %s" %iface_num2)
+            logger.error("fail to attach a interface to domain: %s" %iface_num2)
             return 1
     except libvirtError, e:
         logger.error("API error message: %s, error code is %s" \
diff --git a/repos/domain/console_mutex.py b/repos/domain/console_mutex.py
index f6cea85..773e13d 100644
--- a/repos/domain/console_mutex.py
+++ b/repos/domain/console_mutex.py
@@ -18,10 +18,10 @@ def console_mutex(params):
 
     try:
         conn = sharedmod.libvirtobj['conn']
-        dom = conn.lookupByName(guest)
+        dom = conn.lookupByName(domain)
 
         if not dom.isActive():
-            raise TestError("Guest '%s' is not active" % guest)
+            raise TestError("Guest '%s' is not active" % domain)
 
         logger.info("Creating stream object")
         stream = conn.newStream(0)
diff --git a/repos/domain/cpu_affinity.py b/repos/domain/cpu_affinity.py
index 47cd30a..5a47ad4 100644
--- a/repos/domain/cpu_affinity.py
+++ b/repos/domain/cpu_affinity.py
@@ -66,7 +66,7 @@ def set_vcpus(util, domobj, domain_name, vcpu):
         timeout -= 10
         logger.info(str(timeout) + "s left")
 
-        logger.info('ping guest')
+        logger.info('ping domain')
 
         if utils.do_ping(ip, 30):
             logger.error('The domain is still active, IP: ' + str(ip))
diff --git a/repos/domain/cpu_topology.py b/repos/domain/cpu_topology.py
index 50876da..9c32b6d 100644
--- a/repos/domain/cpu_topology.py
+++ b/repos/domain/cpu_topology.py
@@ -122,7 +122,7 @@ def domain_start(domobj, guestname, util, logger):
 
 def cpu_topology_check(ip, username, password,
                        sockets, cores, threads, util, logger):
-    """login the guest, run lscpu command to check the result"""
+    """login the domain, run lscpu command to check the result"""
     lscpu = "lscpu"
     # sleep for 5 seconds
     time.sleep(40)
diff --git a/repos/domain/destroy.py b/repos/domain/destroy.py
index 0951f95..5245e63 100644
--- a/repos/domain/destroy.py
+++ b/repos/domain/destroy.py
@@ -77,7 +77,7 @@ def destroy(params):
             timeout -= 10
             logger.info(str(timeout) + "s left")
 
-            logger.info('ping guest')
+            logger.info('ping domain')
 
             if utils.do_ping(ip, 30):
                 logger.error('The domain is still active, IP: ' + str(ip))
diff --git a/repos/domain/detach_disk.py b/repos/domain/detach_disk.py
index c7a9ccb..303c953 100644
--- a/repos/domain/detach_disk.py
+++ b/repos/domain/detach_disk.py
@@ -66,7 +66,7 @@ def detach_disk(params):
         if  check_detach_disk(disk_num1, disk_num2):
             logger.info("current disk number: %s\n" %disk_num2)
         else:
-            logger.error("fail to detach a disk to guest: %s\n" %disk_num2)
+            logger.error("fail to detach a disk to domain: %s\n" %disk_num2)
             return 1
     except libvirtError, e:
         logger.error("API error message: %s, error code is %s" \
diff --git a/repos/domain/detach_interface.py b/repos/domain/detach_interface.py
index dc101c2..e940386 100644
--- a/repos/domain/detach_interface.py
+++ b/repos/domain/detach_interface.py
@@ -67,7 +67,7 @@ def detach_interface(params):
         if  check_detach_interface(iface_num1, iface_num2):
             logger.info("current interface number: %s" % iface_num2)
         else:
-            logger.error("fail to detach a interface to guest: %s" %
+            logger.error("fail to detach a interface to domain: %s" %
                           iface_num2)
             return 1
     except libvirtError, e:
diff --git a/repos/domain/domain_list.py b/repos/domain/domain_list.py
index d9f136c..9b133a1 100644
--- a/repos/domain/domain_list.py
+++ b/repos/domain/domain_list.py
@@ -50,7 +50,7 @@ def check_all_option(logger):
         else:
             domain = entry[:-4]
             if domain not in ret:
-                logger.error("domain %s not in the output of virsh list" % guest)
+                logger.error("domain %s not in the output of virsh list" % domain)
                 return 1
     return 0
 
@@ -80,7 +80,7 @@ def check_inactive_option(logger):
                 continue
             else:
                 domain = entry[:-4]
-                inactive_domain.append(guest)
+                inactive_domain.append(domain)
 
     inactive_output = ret.split('\n')
     if inactive_output[0] == '':
@@ -109,7 +109,7 @@ def check_default_option(logger):
             continue
         else:
             domain = entry[:-4]
-            running_domain.append(guest)
+            running_domain.append(domain)
 
     active_output = ret.split('\n')
     if active_output[0] == '':
diff --git a/repos/domain/eventhandler.py b/repos/domain/eventhandler.py
index c90a8a8..5e4dc58 100644
--- a/repos/domain/eventhandler.py
+++ b/repos/domain/eventhandler.py
@@ -89,7 +89,7 @@ def lifecycle_callback(conn, domain, event, detail, opaque):
     STATE = eventToString(event)
 
 def shutdown_event(domobj, guestname, timeout, logger):
-    """shutdown the guest, then check the event infomation"""
+    """shutdown the domain, then check the event infomation"""
     global STATE
     STATE = None
     logger.info("power off %s" % guestname)
@@ -119,7 +119,7 @@ def shutdown_event(domobj, guestname, timeout, logger):
     return 0
 
 def bootup_event(domobj, guestname, timeout, logger):
-    """bootup the guest, then check the event infomation"""
+    """bootup the domain, then check the event infomation"""
     global STATE
     STATE = None
     logger.info("boot up domain %s" % guestname)
@@ -149,7 +149,7 @@ def bootup_event(domobj, guestname, timeout, logger):
     return 0
 
 def suspend_event(domobj, guestname, timeout, logger):
-    """suspend the guest, then check the event infomation"""
+    """suspend the domain, then check the event infomation"""
     global STATE
     STATE = None
     logger.info("suspend domain %s" % guestname)
@@ -179,7 +179,7 @@ def suspend_event(domobj, guestname, timeout, logger):
     return 0
 
 def resume_event(domobj, guestname, timeout, logger):
-    """resume the guest, then check the event infomation"""
+    """resume the domain, then check the event infomation"""
     global STATE
     STATE = None
     logger.info("resume domain %s" % guestname)
diff --git a/repos/domain/ifstats.py b/repos/domain/ifstats.py
index c6c1402..bc8bc0b 100644
--- a/repos/domain/ifstats.py
+++ b/repos/domain/ifstats.py
@@ -53,9 +53,9 @@ def ifstats(params):
     logger.info("get ip by mac address")
     ip = utils.mac_to_ip(mac, 180)
 
-    logger.info('ping guest')
+    logger.info('ping domain')
     if not utils.do_ping(ip, 300):
-        logger.error('Failed on ping guest, IP: ' + str(ip))
+        logger.error('Failed on ping domain, IP: ' + str(ip))
         return 1
 
     xml = domobj.XMLDesc(0)
diff --git a/repos/domain/resume.py b/repos/domain/resume.py
index f37c4fc..339a1b9 100644
--- a/repos/domain/resume.py
+++ b/repos/domain/resume.py
@@ -50,9 +50,9 @@ def resume(params):
     logger.info("get ip by mac address")
     ip = utils.mac_to_ip(mac, 120)
 
-    logger.info('ping guest')
+    logger.info('ping domain')
     if not utils.do_ping(ip, 300):
-        logger.error('Failed on ping guest, IP: ' + str(ip))
+        logger.error('Failed on ping domain, IP: ' + str(ip))
         return 1
 
     logger.info("PASS")
diff --git a/repos/domain/save.py b/repos/domain/save.py
index 9db0667..b91bb3a 100644
--- a/repos/domain/save.py
+++ b/repos/domain/save.py
@@ -47,7 +47,7 @@ def check_domain_status(*args):
 
 def check_domain_save(*args):
     """Check save domain result, if save domain is successful,
-       guestname.save will exist under /tmp directory and guest
+       guestname.save will exist under /tmp directory and domain
        can't be ping and status is paused
     """
     (guestname, domobj, util, logger) = args
diff --git a/repos/domain/shutdown.py b/repos/domain/shutdown.py
index 510fac5..802ddec 100644
--- a/repos/domain/shutdown.py
+++ b/repos/domain/shutdown.py
@@ -61,7 +61,7 @@ def shutdown(params):
         logger.error('The domain state is not equal to "shutoff"')
         return 1
 
-    logger.info('ping guest')
+    logger.info('ping domain')
     if utils.do_ping(ip, 300):
         logger.error('The domain is still active, IP: ' + str(ip))
         return 1
diff --git a/repos/domain/start.py b/repos/domain/start.py
index fb210fb..3ef0d90 100644
--- a/repos/domain/start.py
+++ b/repos/domain/start.py
@@ -89,9 +89,9 @@ def start(params):
         logger.info("get ip by mac address")
         ip = utils.mac_to_ip(mac, 180)
 
-        logger.info('ping guest')
+        logger.info('ping domain')
         if not utils.do_ping(ip, 300):
-            logger.error('Failed on ping guest, IP: ' + str(ip))
+            logger.error('Failed on ping domain, IP: ' + str(ip))
             return 1
 
     logger.info("PASS")
diff --git a/repos/domain/suspend.py b/repos/domain/suspend.py
index b427994..0f58c23 100644
--- a/repos/domain/suspend.py
+++ b/repos/domain/suspend.py
@@ -54,7 +54,7 @@ def suspend(params):
 
     time.sleep(10)
 
-    logger.info('ping guest')
+    logger.info('ping domain')
     if utils.do_ping(ip, 20):
         logger.error('The domain is still active, IP: ' + str(ip))
         return 1
diff --git a/repos/regression/multiple_thread_block_on_domain_create.py b/repos/regression/multiple_thread_block_on_domain_create.py
index 967b1b9..ab36961 100644
--- a/repos/regression/multiple_thread_block_on_domain_create.py
+++ b/repos/regression/multiple_thread_block_on_domain_create.py
@@ -47,7 +47,7 @@ def request_credentials(credentials, user_data):
 
 
 class domain_install(Thread):
-    """function callable by as a thread to create guest
+    """function callable by as a thread to create domain
     """
     def __init__(self, name, os, arch, type, ks, conn, util, logger):
         Thread.__init__(self)
diff --git a/repos/snapshot/delete.py b/repos/snapshot/delete.py
index 98dcad6..8e6150f 100644
--- a/repos/snapshot/delete.py
+++ b/repos/snapshot/delete.py
@@ -39,7 +39,7 @@ def delete_check(guestname, snapshotname, expected_flag, logger):
 
 
 def delete(params):
-    """ snapshot revert a snapshot for a given guest,
+    """ snapshot revert a snapshot for a given domain,
         this case could be with other cases togerther to
         check the functionality of snapshot
     """
diff --git a/repos/snapshot/file_flag.py b/repos/snapshot/file_flag.py
index dffbefb..d2777f8 100644
--- a/repos/snapshot/file_flag.py
+++ b/repos/snapshot/file_flag.py
@@ -46,7 +46,7 @@ def make_flag(ipaddr, username, password, logger):
         return True
 
 def file_flag(params):
-    """ create a new file in the /tmp folder of the guest
+    """ create a new file in the /tmp folder of the domain
         as a flag
     """
     logger = params['logger']
diff --git a/repos/snapshot/internal_create.py b/repos/snapshot/internal_create.py
index 21831bb..335e2a0 100644
--- a/repos/snapshot/internal_create.py
+++ b/repos/snapshot/internal_create.py
@@ -40,7 +40,7 @@ def check_domain_image(domobj, util, guestname, logger):
             return False
 
 def internal_create(params):
-    """ create an internal snapshot for a given guest,
+    """ create an internal snapshot for a given domain,
         this case could be with other cases togerther to
         check the functionality of snapshot
     """
diff --git a/repos/snapshot/revert.py b/repos/snapshot/revert.py
index 380ed6d..94d7e85 100644
--- a/repos/snapshot/revert.py
+++ b/repos/snapshot/revert.py
@@ -23,7 +23,7 @@ def check_domain_state(conn, guestname, logger):
         return True
 
 def revert(params):
-    """ snapshot revert a snapshot for a given guest,
+    """ snapshot revert a snapshot for a given domain,
         this case could be with other cases togerther to
         check the functionality of snapshot
     """
diff --git a/repos/domain/console_io.py b/repos/domain/console_io.py
index 65f41ed..b63e0de 100644
--- a/repos/domain/console_io.py
+++ b/repos/domain/console_io.py
@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # test console interactions
 # This test sends contents of file 'input' to the guest's console
 # and reads from the console the reply and compares it to 'expect' or
 # writes the output to file 'output'
 
@@ -34,9 +34,9 @@ def console_io(params):
 
     try:
         conn = sharedmod.libvirtobj['conn']
-        dom = conn.lookupByName(guest)
+        dom = conn.lookupByName(domain)
         if not dom.isActive():
-            raise TestError("Guest '%s' not active" % guest)
+            raise TestError("Guest '%s' not active" % domain)
 
         logger.info("Creating stream object")
         stream = conn.newStream(0)
@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # test console interactions
-# This test sends contents of file 'input' to the guest's console
+# This test sends contents of file 'input' to the domain's console
 # and reads from the console the reply and compares it to 'expect' or
 # writes the output to file 'output'
diff --git a/repos/domain/install_linux_check.py b/repos/domain/install_linux_check.py
index 62b39bb..97778b3 100644
--- a/repos/domain/install_linux_check.py
+++ b/repos/domain/install_linux_check.py
@@ -30,7 +30,7 @@ HOME_PATH = os.getcwd()
 
 def install_linux_check(params):
     """check domain status after installation, including network ping,
-       read/write option in guest. return value: 0 - ok; 1 - bad
+       read/write option in domain. return value: 0 - ok; 1 - bad
     """
     global logger
     logger = params['logger']
@@ -92,7 +92,7 @@ def install_linux_check(params):
         Test_Result = 1
         return Test_Result
 
     # Creat file and read file in guest.
     logger.info("check point2: creat and read dirctory/file in domain")
     if utils.create_dir(ipaddr, "root", "redhat") == 0:
         logger.info("create dir - /tmp/test successfully")
@@ -145,8 +145,8 @@ def install_linux_check(params):
         Test_Result = 1
         return Test_Result
 
-    # Check app works fine in guest, such as: wget
-    logger.info("check point5: check app works fine in guest, such as: wget")
+    # Check app works fine in domain, such as: wget
+    logger.info("check point5: check app works fine in domain, such as: wget")
     logger.info("get system environment information")
     envfile = os.path.join(HOME_PATH, 'global.cfg')
     logger.info("the environment file is %s" % envfile)
@@ -155,13 +155,13 @@ def install_linux_check(params):
     file_url = global_parser.get_value("other", "wget_url")
 
     if utils.run_wget_app(ipaddr, "root", "redhat", file_url, logger) == 0:
-        logger.info("run wget successfully in guest.")
+        logger.info("run wget successfully in domain.")
     else:
         logger.error("Error: fail to run wget in domain")
         Test_Result = 1
         return Test_Result
 
     # Check nic and blk driver in guest
     if 'kvm' in virt_type or 'xenfv' in virt_type:
         logger.info("check point6: check nic and blk driver in domain is \
                      expected as your config:")
@@ -92,7 +92,7 @@ def install_linux_check(params):
         return Test_Result
 
-    # Creat file and read file in guest.
+    # Creat file and read file in domain.
     logger.info("check point2: creat and read dirctory/file in domain")
     if utils.create_dir(ipaddr, "root", "redhat") == 0:
@@ -155,13 +155,13 @@ def install_linux_check(params):
         return Test_Result
 
-    # Check nic and blk driver in guest
+    # Check nic and blk driver in domain
     if 'kvm' in virt_type or 'xenfv' in virt_type:
         logger.info("check point6: check nic and blk driver in domain is \
diff --git a/utils/utils.py b/utils/utils.py
index da68718..5cd3ed2 100644
--- a/utils/utils.py
+++ b/utils/utils.py
@@ -686,7 +686,7 @@ def validate_remote_nic_type(hostname, username,
         status1, output1 = commands.getstatusoutput(cmd1)
         status2, output2 = commands.getstatusoutput(cmd2)
         if status1 == 0 and status2 == 0:
             # other nic should not be seen in guest
             nic_type_to_name_dict.pop(nic_type)
             for key in nic_type_to_name_dict.keys():
                 logger.info("now try to grep other nic type \
@@ -696,7 +696,7 @@ def validate_remote_nic_type(hostname, username,
                 ret, out = commands.getstatusoutput(other_name_cmd)
                 if ret == 0:
                     logger.info("unspecified nic name is seen in \
-                               guest's lspci command: \n %s \n" % out)
+                               domain's lspci command: \n %s \n" % out)
                     return 1
 
             nic_type_to_driver_dict.pop(nic_type)
@@ -709,7 +709,7 @@ def validate_remote_nic_type(hostname, username,
                 ret1, out1 = commands.getstatusoutput(other_driver_cmd)
                 if ret1 == 0:
                     logger.info("unspecified nic driver is seen \
-                               in guest's lsmod command: %s" % out)
+                               in domain's lsmod command: %s" % out)
                     return 1
 
             logger.info("lspci ouput about nic is: \n %s; \n \
@@ -758,7 +758,7 @@ def validate_remote_blk_type(hostname, username, password,
 
         # this check will not check ide type block device
         if blk_type == "ide":
             # virtio block device should not be seen in guest
             blk_type_to_name_dict.pop(blk_type)
             for key in blk_type_to_name_dict.keys():
                 logger.info(
@@ -768,7 +768,7 @@ def validate_remote_blk_type(hostname, username, password,
                                  (lspci_cmd_ret, blk_type_to_name_dict[key])
                 ret, out = commands.getstatusoutput(other_name_cmd)
                 if ret == 0:
-                    logger.info("unspecified blk name is seen in guest's \
+                    logger.info("unspecified blk name is seen in domain's \
                                 lspci command: \n %s \n" % out)
                     return 1
             blk_type_to_driver_dict.pop(blk_type)
@@ -782,7 +782,7 @@ def validate_remote_blk_type(hostname, username, password,
                 ret1, out1 = commands.getstatusoutput(other_driver_cmd)
                 if ret1 == 0:
                     logger.info("unspecified blk driver is seen \
-                                in guest's lsmod command: \n %s \n" % out)
+                                in domain's lsmod command: \n %s \n" % out)
                     return 1
             logger.info("block device type is ide")
             return 0
@@ -686,7 +686,7 @@ def validate_remote_nic_type(hostname, username,
         status2, output2 = commands.getstatusoutput(cmd2)
         if status1 == 0 and status2 == 0:
-            # other nic should not be seen in guest
+            # other nic should not be seen in domain
             nic_type_to_name_dict.pop(nic_type)
             for key in nic_type_to_name_dict.keys():
@@ -758,7 +758,7 @@ def validate_remote_blk_type(hostname, username, password,
         # this check will not check ide type block device
         if blk_type == "ide":
-            # virtio block device should not be seen in guest
+            # virtio block device should not be seen in domain
             blk_type_to_name_dict.pop(blk_type)
             for key in blk_type_to_name_dict.keys():
-- 
1.7.7.3




More information about the libvir-list mailing list